# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require_relative '../../../db2_config/lib/puppet_x/enterprisemodules/db2/core'
require_relative '../../../db2_config/lib/puppet_x/enterprisemodules/db2/fact'

{
  :db2_secadm_grantees => :securityadmauth,
  :db2_dbadm_grantees => :dbadmauth,
  :db2_sqladm_grantees => :sqladmauth,
  :db2_dataaccess_grantees => :dataaccessauth,
  :db2_accessctrl_grantees => :accessctrlauth,
  :db2_wlmadm_grantees => :wlmadmauth,
  :db2_creatab_grantees => :createtabauth,
  :db2_bindadd_grantees => :bindaddauth,
  :db2_connect_grantees => :connectauth,
  :db2_load_grantees => :loadauth,
  :db2_externalroutine_grantees => :externalroutineauth,
  :db2_quiesceconnect_grantees => :quiesceconnectauth,
  :db2_schemaadm_grantees => :schemaadmauth
}.each do |fact, property|
  Facter.add(fact) do
    extend PuppetX::Db2::Fact

    confine do
      Puppet.features.db2_running?
    end

    db2_array_fact(:name => 'GRANTEE', :type => 'GRANTEETYPE', :database => :database, :instance => :instance) do
      "select distinct grantee, granteetype from syscat.dbauth where #{property} = 'Y'"
    end
  end
end



Facter.add(:db2_roles) do
  extend PuppetX::Db2::Fact

  confine do
    Puppet.features.db2_running?
  end

  db2_array_fact(:name => 'ROLENAME', :database => :database, :instance => :instance) do
    "select rolename from syscat.roleauth where grantortype <> 'S' group by rolename"
  end
end

Facter.add(:db2_nested_roles) do
  extend PuppetX::Db2::Fact

  confine do
    Puppet.features.db2_running?
  end

  db2_array_fact(:name => 'ROLENAME', :grantee => 'GRANTEE', :database => :database, :instance => :instance) do
    'select grantee, rolename from syscat.roleauth where grantee in (select rolename from syscat.roles)'
  end
end
