# frozen_string_literal: true

#
# @summary : determine the benchmark to be used for the manifest
#
# This function determins the  product_version to use for this call. It uses the following algorithmn:
#
# 1. Use the specified version for this database
# 2. Use a generic specified version for all databases
# 3. Check if fact db2_version is set. If not, return an undef
# 4. Use the version based on the version of the database
#
# @param [String[1]] database The database database
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function('db2_secured::default_product_version') do
  dispatch :default_product_version do
    param 'String[1]', :database_identifier
  end

  def default_product_version(database_identifier)
    instance, database = database_identifier.split('/')
    #
    # When a version is specified, use it.
    #
    value = lookup_setting('product_version', nil)
    return value if value
    #
    # When the version fact is available, use it
    #
    return nil unless closure_scope.include?('db2_instances')

    product_version = closure_scope['db2_instances'][instance]['version']
    case product_version
    when /^10\..*/
      'db10'
    when /^11\..*/
      'db11'
    else
      fail "Database version #{product_version} not recognised"
    end
  end

  def lookup_setting(database, default_value)
    call_function('db2_secured::lookup_setting', database, default_value)
  end
end
