#
# db2_secured::controls::database_manager_configuration_parameter_alternate_auth_enc
#
# @summary The `ALTERNATE_AUTH_ENC` database manager configuration parameter specifies the encryption algorithm that is used to encrypt user ID and password that are sent from the client during a connect or attach.
# This parameter is in effect when the authentication method that is negotiated between the client and the server is `SERVER_ENCRYPT`.
# 
# It is recommended to set this parameter to `AES_ONLY`.
# 
# Rationale:
# 
# If this parameter is set to a value other than `AES_ONLY`, the server can accept the DES encryption algorithm to encrypt the user credentials and DES is cryptographically weak in comparison to AES.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 5.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::database_manager_configuration_parameter_alternate_auth_enc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::database_manager_configuration_parameter_alternate_auth_enc::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_manager_configuration_parameter_alternate_auth_enc` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::database_manager_configuration_parameter_alternate_auth_enc {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "database_manager_configuration_parameter_alternate_auth_enc on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]alternate_auth_enc":
    allow_create   => true,
    allow_redefine => true,
    value          => 'AES_ONLY',
  }
}
