#
# db2_secured::controls::limit_os_privileges_of_fenced_mode_process
#
# @summary The `DB2_LIMIT_FENCED_GROUP` registry variable allows restricting the operating system privileges of the fenced mode process (db2fmp) to the privileges assigned to the `DB2USERS` group.
# This variable only has effect if extended security is enabled (`DB2_EXTSEC`) and the Db2 Service Account is not LocalSystem.
# This registry variable only applies to Db2 Servers running on Windows.
# 
# Rationale:
# 
# By default, the fenced mode process has access to both the DB2ADMNS and DB2USERS groups.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.5
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::limit_os_privileges_of_fenced_mode_process: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::limit_os_privileges_of_fenced_mode_process::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `limit_os_privileges_of_fenced_mode_process` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::limit_os_privileges_of_fenced_mode_process {
  db2_secured_setup { "limit_os_privileges_of_fenced_mode_process on ${title}":
    ensure => 'present',
  }

  if $facts['kernel'] == 'Windows' {
    alert('Specified CIS control is not yet automatically enforced.')
  } else {
    debug('Specified CIS control is not applicable on current kernel')
  }
}
