#
# db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid
#
# @summary The table function `SYSPROC.
# AUTH_LIST_AUTHORITIES_FOR_AUTHID` returns the instance and database authorities for the specified authorization ID. In a non-restrictive database this table function has `EXECUTE`  granted to public. It is recommended that public should not be able to execute this routine.
# 
# Rationale:
# 
# A malicious user may use this function to conduct information gathering regarding users that have high level authorities.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.4.4
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.4.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `restrict_access_to_sysproc_auth_list_authorities_for_authid` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid {
  db2_secured_setup { "restrict_access_to_sysproc_auth_list_authorities_for_authid on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSPROC.AUTHORIZATIONIDS": }
}
