#
# db2_secured::controls::review_role_members
#
# @summary Having roles that have been granted specific privileges, then assigning users to the roles, is usually considered the best way to grant application access.
# Because granting privileges to individual users can be more difficult to track and maintain against unauthorized access, users should be assigned to organization-defined database roles according to the needs of the business. As users leave the organization or change responsibilities within the organization, the appropriate roles for them change as well, so role membership needs to be reviewed and verified periodically.
# 
# Rationale:
# 
# Users who have excessive privileges not needed to do their jobs pose an unnecessary risk to the organization as an insider threat.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::review_role_members: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::review_role_members::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `review_role_members` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::review_role_members {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "review_role_members on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
