#
# db2_secured::controls::review_roles_granted_to_public
#
# @summary Granting to `PUBLIC` increases the risk of unauthorized entry into the database.
# Because `PUBLIC` is accessible by any database user, it is important to understand the exposure it has on all database objects. It would make sense to grant role membership to `PUBLIC` if all users required all the privileges granted through that role.
# 
# Rationale:
# 
# As any role granted to `PUBLIC` can potentially allow the compromise of database availability, confidentiality, or integrity, these roles should be restricted according to the needs of the business.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::review_roles_granted_to_public: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::review_roles_granted_to_public::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `review_roles_granted_to_public` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::review_roles_granted_to_public {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "review_roles_granted_to_public on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
