#
# db2_secured::controls::secure_externalroutine_authority
#
# @summary The `EXTERNALROUTINE` authority grants a user the privilege to create user-defined functions and procedures in a specific database.
# Rationale:
# 
# All users with this authority should be regularly reviewed and approved.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.15
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 6.1.15
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_externalroutine_authority: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_externalroutine_authority::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_externalroutine_authority` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_externalroutine_authority (
  Array $user_list = db2_secured::lookup_setting('user_list', []),
  Array $group_list = db2_secured::lookup_setting('group_list', []),
) {
  db2_secured_setup { "secure_externalroutine_authority on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_right { "${title}/externalroutine":
    user_list  => $user_list,
    group_list => $user_list,
  }
}
