#
# db2_secured::controls::secure_the_database_container_directory
#
# @summary 
# A DB2 database container is the physical storage of the data. Rationale:The containers are needed in order for the database to operate properly. The loss of the containers can cause down time. Also, allowing excessive access to the containers may help an attacker to gain access to their contents. Therefore, secure the location(s) of the containers by restricting the access and ownership. Allow only the instance owner to have access to the tablespace containers.## Excelent Compliance Solution.Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 2.2## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with three ways:1) Add `db2_secured::controls::secure_the_database_container_directory: skip` to your hiera data. This will skip this control for **ALL** databases.  2) Add `db2_secured::controls::secure_the_database_container_directory::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  3) Add an entry with the content `secure_the_database_container_directory` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_database_container_directory {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "secure_the_database_container_directory on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
