#
# db2_secured::controls::secure_the_permission_of_the_ibmldapsecurity_ini_file
#
# @summary The `IBMLDAPSecurity.
# ini` file contains the IBM LDAP security plug-in configurations.
# 
# Rationale:
# 
# Recommended value is read and write access to DB2 administrators only and read-only to Everyone/Other/Users/Domain Users. This will ensure that the parameter file is protected. Note: the file is located under INSTANCE_HOME/sqllib/cfg/, for Linux; and %DB2PATH%\cfg\, for Windows.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_the_permission_of_the_ibmldapsecurity_ini_file: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_the_permission_of_the_ibmldapsecurity_ini_file::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_the_permission_of_the_ibmldapsecurity_ini_file` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_permission_of_the_ibmldapsecurity_ini_file {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  if  $facts['db2_instances'] {
    $home     = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "secure_the_permission_of_the_ibmldapsecurity_ini_file on ${title}":
      ensure => 'present',
    }

    -> file { "${home}/sqllib/cfg/IBMLDAPSecurity.ini":
      mode => '0664',
    }
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
