#
# db2_secured::controls::set_umask_value_for_db2_admin_user_profile_file
#
# @summary The DB2 Admin .
# profile file in Linux sets the environment variables and the settings for the user.
# 
# Rationale:
# 
# The umask value should be set to 022 for the owner of the DB2 software at all times.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 2.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_umask_value_for_db2_admin_user_profile_file: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_umask_value_for_db2_admin_user_profile_file::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_umask_value_for_db2_admin_user_profile_file` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_umask_value_for_db2_admin_user_profile_file {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "set_umask_value_for_db2_admin_user_profile_file on ${title}":
    ensure => 'present',
  }

  -> file_line { "umask set for instance ${instance}":
    path => "/home/${instance}/.bash_profile",
    line => 'umask 022',
  }
}
